@@ -136,10 +136,12 @@ static char **complete_agent(const char *text, int start, int end)
 }
 
 /* Return how many parameters we have typed */
-static int calc_level(char *line)
+int __connmanctl_input_calc_level(void)
 {
 	int count = 0;
-	char *ptr = line;
+	char *ptr;
+
+	ptr = rl_line_buffer;
 
 	while (*ptr) {
 		if (*ptr == ' ') {
@@ -155,16 +157,9 @@ static int calc_level(char *line)
 	return count;
 }
 
-static char *get_command_name(char *line)
+void __connmanctl_input_lookup_end(void)
 {
-	char *start, *ptr;
-
-	start = ptr = line;
-
-	while (*ptr && *ptr != ' ')
-		ptr++;
-
-	return g_strndup(start, ptr - start);
+	rl_attempted_completion_over = 1;
 }
 
 static char **complete_command(const char *text, int start, int end)
@@ -175,24 +170,14 @@ static char **complete_command(const char *text, int start, int end)
 
 	} else {
 		__connmanctl_lookup_cb cb;
-		char *current_command;
 		char **str = NULL;
 
-		if (calc_level(rl_line_buffer) > 1) {
-			rl_attempted_completion_over = 1;
-			return NULL;
-		}
-
-		current_command = get_command_name(rl_line_buffer);
-
-		cb = __connmanctl_get_lookup_func(current_command);
+		cb = __connmanctl_get_lookup_func(rl_line_buffer);
 		if (cb)
 			str = rl_completion_matches(text, cb);
 		else
 			rl_attempted_completion_over = 1;
 
-		g_free(current_command);
-
 		return str;
 	}
 }
@@ -229,6 +214,16 @@ void __connmanctl_command_mode(void)
 	rl_attempted_completion_function = complete_command;
 }
 
+static void no_handler(char *input)
+{
+}
+
+static void no_handler_mode(void)
+{
+	rl_callback_handler_install("", no_handler);
+	rl_attempted_completion_function = NULL;
+}
+
 int __connmanctl_input_init(int argc, char *argv[])
 {
 	char *help[] = {
@@ -264,6 +259,7 @@ int __connmanctl_input_init(int argc, char *argv[])
 
 	} else {
 		interactive = false;
+		no_handler_mode();
 
 		if (strcmp(argv[1], "--help") == 0 ||
 				strcmp(argv[1], "-h") == 0)
@@ -282,11 +278,11 @@ int __connmanctl_input_init(int argc, char *argv[])
 
 	g_source_remove(source);
 
-	if (interactive == true) {
+	if (interactive)
 		__connmanctl_monitor_completions(NULL);
-		rl_callback_handler_remove();
-		rl_message("");
-	}
+
+	rl_callback_handler_remove();
+	rl_message("");
 
 	dbus_connection_unref(connection);
 	if (main_loop)
