@@ -37,14 +37,14 @@ extern "C" {
 struct connman_technology;
 
 void connman_technology_tethering_notify(struct connman_technology *technology,
-							connman_bool_t enabled);
+							bool enabled);
 int connman_technology_set_regdom(const char *alpha2);
 void connman_technology_regdom_notify(struct connman_technology *technology,
 							const char *alpha2);
 
-connman_bool_t connman_technology_get_wifi_tethering(const char **ssid,
+bool connman_technology_get_wifi_tethering(const char **ssid,
 							const char **psk);
-connman_bool_t connman_technology_is_tethering_allowed(enum connman_service_type type);
+bool connman_technology_is_tethering_allowed(enum connman_service_type type);
 
 struct connman_technology_driver {
 	const char *name;
@@ -59,7 +59,7 @@ struct connman_technology_driver {
 								int index);
 	int (*set_tethering) (struct connman_technology *technology,
 				const char *identifier, const char *passphrase,
-				const char *bridge, connman_bool_t enabled);
+				const char *bridge, bool enabled);
 	int (*set_regdom) (struct connman_technology *technology,
 						const char *alpha2);
 };
