@@ -56,6 +56,7 @@ static char *default_blacklist[] = {
 	"vmnet",
 	"vboxnet",
 	"virbr",
+	"ifb",
 	NULL
 };
 
@@ -255,14 +256,14 @@ static void parse_config(GKeyFile *config)
 
 	g_clear_error(&error);
 
-	timeservers = g_key_file_get_string_list(config, "General",
+	timeservers = __connman_config_get_string_list(config, "General",
 					CONF_PREF_TIMESERVERS, NULL, &error);
 	if (!error)
 		connman_settings.pref_timeservers = timeservers;
 
 	g_clear_error(&error);
 
-	str_list = g_key_file_get_string_list(config, "General",
+	str_list = __connman_config_get_string_list(config, "General",
 			CONF_AUTO_CONNECT, &len, &error);
 
 	if (!error)
@@ -276,7 +277,7 @@ static void parse_config(GKeyFile *config)
 
 	g_clear_error(&error);
 
-	str_list = g_key_file_get_string_list(config, "General",
+	str_list = __connman_config_get_string_list(config, "General",
 			CONF_PREFERRED_TECHS, &len, &error);
 
 	if (!error)
@@ -287,7 +288,7 @@ static void parse_config(GKeyFile *config)
 
 	g_clear_error(&error);
 
-	str_list = g_key_file_get_string_list(config, "General",
+	str_list = __connman_config_get_string_list(config, "General",
 			CONF_FALLBACK_NAMESERVERS, &len, &error);
 
 	if (!error)
@@ -312,7 +313,7 @@ static void parse_config(GKeyFile *config)
 
 	g_clear_error(&error);
 
-	interfaces = g_key_file_get_string_list(config, "General",
+	interfaces = __connman_config_get_string_list(config, "General",
 			CONF_BLACKLISTED_INTERFACES, &len, &error);
 
 	if (!error)
@@ -323,7 +324,7 @@ static void parse_config(GKeyFile *config)
 
 	g_clear_error(&error);
 
-	boolean = g_key_file_get_boolean(config, "General",
+	boolean = __connman_config_get_bool(config, "General",
 					CONF_ALLOW_HOSTNAME_UPDATES,
 					&error);
 	if (!error)
@@ -331,14 +332,14 @@ static void parse_config(GKeyFile *config)
 
 	g_clear_error(&error);
 
-	boolean = g_key_file_get_boolean(config, "General",
+	boolean = __connman_config_get_bool(config, "General",
 			CONF_SINGLE_TECH, &error);
 	if (!error)
 		connman_settings.single_tech = boolean;
 
 	g_clear_error(&error);
 
-	tethering = g_key_file_get_string_list(config, "General",
+	tethering = __connman_config_get_string_list(config, "General",
 			CONF_TETHERING_TECHNOLOGIES, &len, &error);
 
 	if (!error)
@@ -346,7 +347,7 @@ static void parse_config(GKeyFile *config)
 
 	g_clear_error(&error);
 
-	boolean = g_key_file_get_boolean(config, "General",
+	boolean = __connman_config_get_bool(config, "General",
 					CONF_PERSISTENT_TETHERING_MODE,
 					&error);
 	if (!error)
@@ -454,10 +455,10 @@ static gchar *option_plugin = NULL;
 static gchar *option_nodevice = NULL;
 static gchar *option_noplugin = NULL;
 static gchar *option_wifi = NULL;
-static bool option_detach = true;
-static bool option_dnsproxy = true;
-static bool option_backtrace = true;
-static bool option_version = false;
+static gboolean option_detach = TRUE;
+static gboolean option_dnsproxy = TRUE;
+static gboolean option_backtrace = TRUE;
+static gboolean option_version = FALSE;
 
 static bool parse_debug(const char *key, const char *value,
 					gpointer user_data, GError **error)
@@ -651,17 +652,16 @@ int main(int argc, char *argv[])
 	__connman_service_init();
 	__connman_provider_init();
 	__connman_network_init();
+	__connman_config_init();
 	__connman_device_init(option_device, option_nodevice);
 
 	__connman_ippool_init();
 	__connman_iptables_init();
-	__connman_nfacct_init();
 	__connman_firewall_init();
 	__connman_nat_init();
 	__connman_tethering_init();
 	__connman_counter_init();
 	__connman_manager_init();
-	__connman_config_init();
 	__connman_stats_init();
 	__connman_clock_init();
 
@@ -718,7 +718,6 @@ int main(int argc, char *argv[])
 	__connman_tethering_cleanup();
 	__connman_nat_cleanup();
 	__connman_firewall_cleanup();
-	__connman_nfacct_cleanup();
 	__connman_iptables_cleanup();
 	__connman_ippool_cleanup();
 	__connman_device_cleanup();
