@@ -117,11 +117,12 @@ static struct timespec mtx_time;
 static int transmit_fd = 0;
 
 static char *timeserver = NULL;
+static struct sockaddr_in timeserver_addr;
 static gint poll_id = 0;
 static gint timeout_id = 0;
 static guint retries = 0;
 
-static void send_packet(int fd, const char *server);
+static void send_packet(int fd, const char *server, uint32_t timeout);
 
 static void next_server(void)
 {
@@ -135,17 +136,19 @@ static void next_server(void)
 
 static gboolean send_timeout(gpointer user_data)
 {
-	DBG("send timeout (retries %d)", retries);
+	uint32_t timeout = GPOINTER_TO_UINT(user_data);
+
+	DBG("send timeout %u (retries %d)", timeout, retries);
 
 	if (retries++ == NTP_SEND_RETRIES)
 		next_server();
 	else
-		send_packet(transmit_fd, timeserver);
+		send_packet(transmit_fd, timeserver, timeout << 1);
 
 	return FALSE;
 }
 
-static void send_packet(int fd, const char *server)
+static void send_packet(int fd, const char *server, uint32_t timeout)
 {
 	struct ntp_msg msg;
 	struct sockaddr_in addr;
@@ -194,12 +197,13 @@ static void send_packet(int fd, const char *server)
 	}
 
 	/*
-	 * Add a retry timeout of two seconds to retry the existing
+	 * Add an exponential retry timeout to retry the existing
 	 * request. After a set number of retries, we'll fallback to
 	 * trying another server.
 	 */
 
-	timeout_id = g_timeout_add_seconds(NTP_SEND_TIMEOUT, send_timeout, NULL);
+	timeout_id = g_timeout_add_seconds(timeout, send_timeout,
+					GUINT_TO_POINTER(timeout));
 }
 
 static gboolean next_poll(gpointer user_data)
@@ -207,7 +211,7 @@ static gboolean next_poll(gpointer user_data)
 	if (!timeserver || transmit_fd == 0)
 		return FALSE;
 
-	send_packet(transmit_fd, timeserver);
+	send_packet(transmit_fd, timeserver, NTP_SEND_TIMEOUT);
 
 	return FALSE;
 }
@@ -250,6 +254,17 @@ static void decode_msg(void *base, size_t len, struct timeval *tv,
 			msg->rootdisp.seconds, msg->rootdisp.fraction);
 	DBG("reference  : 0x%04x", msg->refid);
 
+	if (!msg->stratum) {
+		/* RFC 4330 ch 8 Kiss-of-Death packet */
+		uint32_t code = ntohl(msg->refid);
+
+		connman_info("Skipping server %s KoD code %c%c%c%c",
+			timeserver, code >> 24, code >> 16 & 0xff,
+			code >> 8 & 0xff, code & 0xff);
+		next_server();
+		return;
+	}
+
 	transmit_delay = LOGTOD(msg->poll);
 
 	if (NTP_FLAGS_LI_DECODE(msg->flags) == NTP_FLAG_LI_NOTINSYNC) {
@@ -345,6 +360,7 @@ static gboolean received_data(GIOChannel *channel, GIOCondition condition,
 							gpointer user_data)
 {
 	unsigned char buf[128];
+	struct sockaddr_in sender_addr;
 	struct msghdr msg;
 	struct iovec iov;
 	struct cmsghdr *cmsg;
@@ -370,11 +386,17 @@ static gboolean received_data(GIOChannel *channel, GIOCondition condition,
 	msg.msg_iovlen = 1;
 	msg.msg_control = aux;
 	msg.msg_controllen = sizeof(aux);
+	msg.msg_name = &sender_addr;
+	msg.msg_namelen = sizeof(sender_addr);
 
 	len = recvmsg(fd, &msg, MSG_DONTWAIT);
 	if (len < 0)
 		return TRUE;
 
+	if (timeserver_addr.sin_addr.s_addr != sender_addr.sin_addr.s_addr)
+		/* only accept messages from the timeserver */
+		return TRUE;
+
 	tv = NULL;
 	clock_gettime(CLOCK_MONOTONIC, &mrx_time);
 
@@ -454,7 +476,7 @@ static void start_ntp(char *server)
 	g_io_channel_unref(channel);
 
 send:
-	send_packet(transmit_fd, server);
+	send_packet(transmit_fd, server, NTP_SEND_TIMEOUT);
 }
 
 int __connman_ntp_start(char *server)
@@ -468,6 +490,7 @@ int __connman_ntp_start(char *server)
 		g_free(timeserver);
 
 	timeserver = g_strdup(server);
+	timeserver_addr.sin_addr.s_addr = inet_addr(server);
 
 	start_ntp(timeserver);
 
